@@ -49,6 +49,7 @@
 #include <akonadi/changerecorder.h>
 #include <akonadi/collectionfetchscope.h>
 #include <akonadi/entitydisplayattribute.h>
+#include <akonadi/itemfetchjob.h>
 #include <akonadi/itemfetchscope.h>
 
 #include <kabc/addressee.h>
@@ -74,6 +75,7 @@ DavGroupwareResource::DavGroupwareResource( const QString &id )
   mDavCollectionRoot.setName( identifier() );
   mDavCollectionRoot.setRemoteId( identifier() );
   mDavCollectionRoot.setContentMimeTypes( QStringList() << Collection::mimeType() );
+  mDavCollectionRoot.setRights( Collection::CanCreateCollection | Collection::CanDeleteCollection | Collection::CanChangeCollection );
 
   EntityDisplayAttribute *attribute = mDavCollectionRoot.attribute<EntityDisplayAttribute>( Collection::AddIfMissing );
   attribute->setIconName( QLatin1String( "folder-remote" ) );
@@ -259,7 +261,11 @@ void DavGroupwareResource::retrieveItems( const Akonadi::Collection &collection
   }
 
   if ( mCollectionsWithTemporaryError.contains( collection.remoteId() ) ) {
-    cancelTask();
+    // Just serve the items from Akonadi
+    kWarning() << "Serving items from Akonadi for" << collection.remoteId();
+    ItemFetchJob *job = new ItemFetchJob( collection );
+    connect( job, SIGNAL(result(KJob*)), this, SLOT(onRetrieveAkonadiItemsFinished(KJob*)) );
+    job->start();
     return;
   }
 
@@ -267,8 +273,8 @@ void DavGroupwareResource::retrieveItems( const Akonadi::Collection &collection
 
   if ( !davUrl.url().isValid() ) {
     kError() << "Can't find a configured URL, collection.remoteId() is " << collection.remoteId();
-    // TODO: make this string translatable
-    cancelTask( "Items requested for an unknown collection" );
+    // Just return an empty list
+    itemsRetrieved( Akonadi::Item::List() );
     //Q_ASSERT_X( false, "DavGroupwareResource::retrieveItems", "Url is invalid" );
     return;
   }
@@ -632,6 +638,17 @@ void DavGroupwareResource::onRetrieveItemsFinished( KJob *job )
   }
 }
 
+void DavGroupwareResource::onRetrieveAkonadiItemsFinished( KJob *job )
+{
+  if ( job->error() ) {
+    itemsRetrieved( Akonadi::Item::List() );
+    return;
+  }
+
+  const ItemFetchJob *j = qobject_cast<ItemFetchJob*>( job );
+  itemsRetrieved( j->items() );
+}
+
 void DavGroupwareResource::onMultigetFinished( KJob *job )
 {
   if ( job->error() ) {
